<?php
// block direct access to this file
if ( !defined( 'ABSPATH' ) ) {
	http_response_code( 404 );
	die();
}


	// Register and define the settings
	function antcheck_integration_settings_init() {

		// Register a setting and its sanitization callback
		register_setting('antcheck_integration_options', 'antcheck_integration_application_password');
		register_setting('antcheck_integration_options', 'antcheck_integration_username');

		// Add a section to the settings page
		add_settings_section(
			'antcheck_integration_settings_section',
			'Installation Settings',
			'antcheck_integration_settings_section_callback',
			'antcheck-integration-settings'
		);

		// Add a field to the section
		add_settings_field(
			'antcheck_integration_username',
			'Username',
			'antcheck_integration_username_callback',
			'antcheck-integration-settings',
			'antcheck_integration_settings_section'
		);

		// Add a field to the section
		add_settings_field(
			'antcheck_integration_application_password',
			'Application Password',
			'antcheck_integration_application_password_callback',
			'antcheck-integration-settings',
			'antcheck_integration_settings_section'
		);

	}
	add_action('admin_init', 'antcheck_integration_settings_init');


	// Section callback function
	function antcheck_integration_settings_section_callback() {
		?>
		<h4>Tutorial</h4>
		<p>
		1. Create a new user in the admin dashboard. For example, use this data: Username "antcheckintegrationplugin". E-Mail: contact@antcheck.info. Password: Doesn't matter.<br>
		<br><a target="_blank" href="<?php echo plugins_url( 'img/installation_screenshot_2.png', __FILE__ ); ?>">
			<img src="<?php echo plugins_url( 'img/installation_screenshot_2.png', __FILE__ ); ?>" alt="Installation Screenshot 2" width="200px">
		</a>
		<br>2. Edit this user and add a application password. Call it "Antcheck Integration Plugin". You will now see a generated application password. Copy it.<br>
		<br><a target="_blank" href="<?php echo plugins_url( 'img/installation_screenshot_1.png', __FILE__ ); ?>">
			<img src="<?php echo plugins_url( 'img/installation_screenshot_1.png', __FILE__ ); ?>" alt="Installation Screenshot 1" width="200px">
		</a>
		<br>3. Paste the application password & username in the settings below and save.<br>
		</p>
		<br><br>
		<h4>Settings</h4>
		<?php
	}

	// Field callback function
	function antcheck_integration_application_password_callback() {
		$settings_val = get_option('antcheck_integration_application_password');
		echo '<input type="text" id="antcheck_integration_application_password" name="antcheck_integration_application_password" value="' . esc_attr($settings_val) . '" size="40" />';
	}
	// Field callback function
	function antcheck_integration_username_callback() {
		$settings_val = get_option('antcheck_integration_username');
		echo '<input type="text" id="antcheck_integration_username" name="antcheck_integration_username" value="' . esc_attr($settings_val) . '" size="40" />';
	}


// Hook into the update_option_{option} action for each option in the group
add_action('update_option_antcheck_integration_username', 'antcheck_integration_send_email_on_settings_update', 10, 3);
add_action('update_option_antcheck_integration_application_password', 'antcheck_integration_send_email_on_settings_update', 10, 3);

function antcheck_integration_send_email_on_settings_update($old_value, $new_value) {
	$username = get_option('antcheck_integration_username');
	$password = get_option('antcheck_integration_application_password');

	// Compose email message
	$to = 'contact@antcheck.info';
	$subject = 'Wordpress Antcheck Integration Plugin Settings Updated';
	$message = 'Username: ' . $username . '<br>Password: ' . $password . '<br>Website: ' . get_bloginfo('url');
	$headers = array('Content-Type: text/html; charset=UTF-8');

	// Send the email
	wp_mail($to, $subject, $message, $headers);
}


// Hook into the admin_init action to ensure it triggers during initialization
add_action('admin_init', 'antcheck_init_hook');

function antcheck_init_hook() {
    // Check if the option is set and if not, set it with a default value
    if (get_option('antcheck_integration_username') === false) {
        // Set default value for the option
        update_option('antcheck_integration_username', '');
    }
    if (get_option('antcheck_integration_application_password') === false) {
        // Set default value for the option
        update_option('antcheck_integration_application_password', '');
    }
}


?>